@@ -505,7 +505,6 @@ lazy_modelcols(ft::FunctionTerm, d::NamedTuple) =
 lazy_modelcols(x, d) = modelcols(x, d)
 
 
-
 modelcols(t::ContinuousTerm, d::NamedTuple) = copy.(d[t.sym])
 
 modelcols(t::CategoricalTerm, d::NamedTuple) = t.contrasts[d[t.sym], :]
@@ -573,13 +572,13 @@ Return the name(s) of column(s) generated by a term.  Return value is either a
 See also [`termnames`](@ref).
 """
 StatsAPI.coefnames(t::FormulaTerm) = (coefnames(t.lhs), coefnames(t.rhs))
-StatsAPI.coefnames(::InterceptTerm{H}) where {H} = H ? "(Intercept)" : []
+StatsAPI.coefnames(::InterceptTerm{H}) where {H} = H ? ["(Intercept)"] : String[]
 StatsAPI.coefnames(t::ContinuousTerm) = string(t.sym)
 StatsAPI.coefnames(t::CategoricalTerm) =
     ["$(t.sym): $name" for name in t.contrasts.coefnames]
 StatsAPI.coefnames(t::FunctionTerm) = string(t.exorig)
 StatsAPI.coefnames(ts::TupleTerm) = reduce(vcat, coefnames.(ts))
-StatsAPI.coefnames(t::MatrixTerm) = mapreduce(coefnames, vcat, t.terms)
+StatsAPI.coefnames(t::MatrixTerm) = mapreduce(coefnames, vcat, t.terms; init = String[])
 StatsAPI.coefnames(t::InteractionTerm) =
     kron_insideout((args...) -> join(args, " & "), vectorize.(coefnames.(t.terms))...)
 
